@@ -1,10 +1,15 @@
-from .functions_1D import (
-    Blackbody, Constant, Cubic, DiracDelta, Exponential_cutoff, Line,
-    Log_parabola, Quadratic, Sin, StepFunction, StepFunctionUpper,
-    has_ebltable, has_gsl, has_naima, Band, Band_Calderone, Band_grbm,
-    Broken_powerlaw, Cutoff_powerlaw, Cutoff_powerlaw_Ep, Inverse_cutoff_powerlaw, Powerlaw,
-    Powerlaw_Eflux, Powerlaw_flux, SmoothlyBrokenPowerLaw, Quartic,
-    get_polynomial, Super_cutoff_powerlaw, PhAbs, TbAbs, WAbs, has_atomdb)
+from .functions_1D import (Band, Band_Calderone, Band_grbm, Blackbody,
+                           Broken_powerlaw, Constant, Cubic, Cutoff_powerlaw,
+                           Cutoff_powerlaw_Ep, DiracDelta, Exponential_cutoff,
+                           Inverse_cutoff_powerlaw, Line, Log_parabola,
+                           ModifiedBlackbody, NonDissipativePhotosphere,
+                           NonDissipativePhotosphere_Deep, PhAbs, Powerlaw,
+                           Powerlaw_Eflux, Powerlaw_flux, Quadratic, Quartic,
+                           Sin, SmoothlyBrokenPowerLaw, Standard_Rv,
+                           StepFunction, StepFunctionUpper,
+                           Super_cutoff_powerlaw, TbAbs, WAbs, ZDust,
+                           get_polynomial, has_atomdb, has_ebltable, has_gsl,
+                           has_naima)
 
 if has_naima:
     from .functions_1D import Synchrotron
@@ -21,10 +26,8 @@ if has_atomdb:
     from .apec import APEC, VAPEC
 
 from .dark_matter.dm_models import DMFitFunction, DMSpectra
-
 from .function import (Function1D, Function2D, Function3D, FunctionMeta,
                        ModelAssertionViolation)
-
 from .functions_2D import (Asymm_Gaussian_on_sphere, Disk_on_sphere,
                            Ellipse_on_sphere, Gaussian_on_sphere,
                            Latitude_galactic_diffuse, Power_law_on_sphere,
@@ -53,7 +56,10 @@ __all__ = [
     "Log_uniform_prior", "Truncated_gaussian", "Uniform_prior",
     "TemplateModel", "TemplateModelFactory", "XSPECTableModel",
     "MissingDataFile", "Log_parabola", "Blackbody", "Function1D", "Function2D",
-    "Function3D", "FunctionMeta", "ModelAssertionViolation", "Quartic", "get_polynomial"
+    "Function3D", "FunctionMeta", "ModelAssertionViolation", "Quartic", "get_polynomial",
+    "ZDust", "Standard_Rv", "ModifiedBlackbody", "NonDissipativePhotosphere", "NonDissipativePhotosphere_Deep",
+
+    
 ]
 
 if has_atomdb:
